AddressBulkResultEntry

Enum AddressBulkResultEntry 

pub enum AddressBulkResultEntry {
    Success {
        address: Address,
    },
    Error {
        message: String,
    },
}
A bulk insert result entry, returned per input record by add_many_addresses_with_meta so that one record failing does not abort the batch. Note that although the success case is much larger than the error case, this is negligible in real life, as we expect a very small success/error ratio.

Variants



Success

Fields

address: Address


Error

Fields

message: String