pub struct UpdatableAddressFieldsWithMeta {
pub fields: UpdatableAddressFields,
pub meta: AddressMeta,
}Expand description
An address together with its metadata, passed to add_address_with_meta and
update_address_with_meta when importing a record from another store.
Fields
fields: UpdatableAddressFieldsmeta: AddressMetaTrait Implementations
Sourceimpl Clone for UpdatableAddressFieldsWithMeta
impl Clone for UpdatableAddressFieldsWithMeta
Sourcefn clone(&self) -> UpdatableAddressFieldsWithMeta
fn clone(&self) -> UpdatableAddressFieldsWithMeta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<UT> ConvertError<UT> for UpdatableAddressFieldsWithMeta
impl<UT> ConvertError<UT> for UpdatableAddressFieldsWithMeta
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Default for UpdatableAddressFieldsWithMeta
impl Default for UpdatableAddressFieldsWithMeta
Sourcefn default() -> UpdatableAddressFieldsWithMeta
fn default() -> UpdatableAddressFieldsWithMeta
Returns the “default value” for a type. Read more
impl<UT> FfiConverter<UT> for UpdatableAddressFieldsWithMeta
impl<UT> FfiConverter<UT> for UpdatableAddressFieldsWithMeta
const TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
type FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
fn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
fn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
impl<UT> Lift<UT> for UpdatableAddressFieldsWithMeta
impl<UT> Lift<UT> for UpdatableAddressFieldsWithMeta
impl<UT> LiftRef<UT> for UpdatableAddressFieldsWithMeta
impl<UT> LiftRef<UT> for UpdatableAddressFieldsWithMeta
impl<UT> LiftReturn<UT> for UpdatableAddressFieldsWithMeta
impl<UT> LiftReturn<UT> for UpdatableAddressFieldsWithMeta
type ReturnType = <UpdatableAddressFieldsWithMeta as Lift<UT>>::FfiType
type ReturnType = <UpdatableAddressFieldsWithMeta as Lift<UT>>::FfiType
FFI return type for trait interfaces
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
impl<UT> Lower<UT> for UpdatableAddressFieldsWithMeta
impl<UT> Lower<UT> for UpdatableAddressFieldsWithMeta
impl<UT> LowerError<UT> for UpdatableAddressFieldsWithMeta
impl<UT> LowerError<UT> for UpdatableAddressFieldsWithMeta
fn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
impl<UT> LowerReturn<UT> for UpdatableAddressFieldsWithMeta
impl<UT> LowerReturn<UT> for UpdatableAddressFieldsWithMeta
type ReturnType = <UpdatableAddressFieldsWithMeta as Lower<UT>>::FfiType
type ReturnType = <UpdatableAddressFieldsWithMeta as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
impl<UT> TypeId<UT> for UpdatableAddressFieldsWithMeta
impl<UT> TypeId<UT> for UpdatableAddressFieldsWithMeta
const TYPE_ID_META: MetadataBuffer